@@ -41,6 +41,19 @@ def getRootPath():
     return SakRootPath
 
 
+# 检测目录或文件是否存在
+def isPathExists(path=""):
+    """
+        检测 目录 或 文件 是否存在
+    :param path: 路径
+    :return:
+    """
+    if path == "":
+        return False
+
+    return os.path.exists(path)
+
+
 # 创建目录（若路径不存在，则递归创建，若存在则不执行）
 def mkdir(path: str):
     """
@@ -50,17 +63,8 @@ def mkdir(path: str):
     :param path: 路径
     :return:
     """
-    if not os.path.exists(path):
+    if not isPathExists(path):
         os.makedirs(path)
         return True
     else:
         return False
-
-
-def isPathExists(path: str):
-    """
-        检测 目录 或 文件 是否存在
-    :param path: 路径
-    :return:
-    """
-    return os.path.exists(path)
