@@ -1,3 +1,7 @@
+import pysak
+import time
+
+
 def getTimestamp(length=10):
     """
         获取当前时刻指定长度的时间戳  10位~17位
